@@ -427,6 +427,9 @@
 #' # Training and evaluating a multinomial model with nnet
 #' #
 #'
+#' # Only run if `nnet` is installed
+#' if (requireNamespace("nnet", quietly = TRUE)){
+#'
 #' # Create a data frame with some predictors and a target column
 #' class_names <- paste0("class_", 1:4)
 #' data_for_nnet <- multiclass_probability_tibble(
@@ -468,6 +471,7 @@
 #'   type = "multinomial"
 #' )
 #' }
+#' }
 evaluate <- function(data,
                      target_col,
                      prediction_cols,
@@ -1082,7 +1086,7 @@ run_internal_evaluate_wrapper <- function(data,
   # Move Process last
   if ("Process" %in% colnames(results)){
     results <- results %>%
-      dplyr::relocate(.data$Process, .after = dplyr::last_col())
+      dplyr::relocate("Process", .after = dplyr::last_col())
   }
 
   # If na.rm != "both" and it contains the NAs_removed column
